[cmclasses] r1229 committed - Updated test classes after restructuring.

0 views
Skip to first unread message

cmcl...@googlecode.com

unread,
May 28, 2015, 3:37:56 AM5/28/15
to cmcl...@googlegroups.com
Revision: 1229
Author: christian.wuerker
Date: Thu May 28 07:36:27 2015 UTC
Log: Updated test classes after restructuring.
https://code.google.com/p/cmclasses/source/detail?r=1229

Added:
/branches/0.8.1/Test/Alg/Math
/branches/0.8.1/Test/CLI
/branches/0.8.1/Test/DB
/branches/0.8.1/Test/FS
/branches/0.8.1/Test/FS/File
/branches/0.8.1/Test/FS/Folder
Deleted:
/branches/0.8.1/Test/Console
/branches/0.8.1/Test/Database
/branches/0.8.1/Test/File
/branches/0.8.1/Test/Folder
/branches/0.8.1/Test/Math
Modified:
/branches/0.8.1/Test/Alg/Math/Algebra/LabelMatrixTest.php
/branches/0.8.1/Test/Alg/Math/Algebra/MatrixTest.php
/branches/0.8.1/Test/Alg/Math/Algebra/VectorTest.php
/branches/0.8.1/Test/Alg/Math/AverageTest.php
/branches/0.8.1/Test/Alg/Math/CompactIntervalTest.php
/branches/0.8.1/Test/Alg/Math/FactorialTest.php
/branches/0.8.1/Test/Alg/Math/Finance/CompoundInterestTest.php
/branches/0.8.1/Test/Alg/Math/FormulaProductTest.php
/branches/0.8.1/Test/Alg/Math/FormulaSumTest.php
/branches/0.8.1/Test/Alg/Math/FormulaTest.php
/branches/0.8.1/Test/Alg/Math/PrimeTest.php
/branches/0.8.1/Test/CLI/Command/ArgumentParserTest.php
/branches/0.8.1/Test/CLI/Command/ProgramTest.php
/branches/0.8.1/Test/DB/BaseConnectionTest.php
/branches/0.8.1/Test/DB/PDO/ConnectionTest.php
/branches/0.8.1/Test/DB/PDO/TableReaderTest.php
/branches/0.8.1/Test/DB/PDO/TableWriterTest.php
/branches/0.8.1/Test/DB/ResultTest.php
/branches/0.8.1/Test/DB/RowTest.php
/branches/0.8.1/Test/DB/StatementBuilderTest.php
/branches/0.8.1/Test/DB/StatementCollectionTest.php
/branches/0.8.1/Test/DB/TableReaderTest.php
/branches/0.8.1/Test/DB/TableWriterTest.php
/branches/0.8.1/Test/FS/File/Arc/BzipTest.php
/branches/0.8.1/Test/FS/File/Arc/GzipTest.php
/branches/0.8.1/Test/FS/File/Arc/TarTest.php
/branches/0.8.1/Test/FS/File/BackupTest.php
/branches/0.8.1/Test/FS/File/Block/ReaderTest.php
/branches/0.8.1/Test/FS/File/Block/WriterTest.php
/branches/0.8.1/Test/FS/File/CSV/IteratorTest.php
/branches/0.8.1/Test/FS/File/CSV/ReaderTest.php
/branches/0.8.1/Test/FS/File/CacheTest.php
/branches/0.8.1/Test/FS/File/Configuration/ConverterTest.php
/branches/0.8.1/Test/FS/File/Configuration/ReaderTest.php
/branches/0.8.1/Test/FS/File/EditorTest.php
/branches/0.8.1/Test/FS/File/ICal/BuilderTest.php
/branches/0.8.1/Test/FS/File/ICal/ParserTest.php
/branches/0.8.1/Test/FS/File/INI/CreatorTest.php
/branches/0.8.1/Test/FS/File/INI/EditorTest.php
/branches/0.8.1/Test/FS/File/INI/ReaderTest.php
/branches/0.8.1/Test/FS/File/INI/SectionEditorTest.php
/branches/0.8.1/Test/FS/File/INI/SectionReaderTest.php
/branches/0.8.1/Test/FS/File/INITest.php
/branches/0.8.1/Test/FS/File/JSON/ReaderTest.php
/branches/0.8.1/Test/FS/File/List/EditorTest.php
/branches/0.8.1/Test/FS/File/List/ReaderTest.php
/branches/0.8.1/Test/FS/File/List/SectionReaderTest.php
/branches/0.8.1/Test/FS/File/List/SectionWriterTest.php
/branches/0.8.1/Test/FS/File/List/WriterTest.php
/branches/0.8.1/Test/FS/File/Log/WriterTest.php
/branches/0.8.1/Test/FS/File/NameFilterTest.php
/branches/0.8.1/Test/FS/File/PHP/Check/MethodVisibilityTest.php
/branches/0.8.1/Test/FS/File/PHP/Parser/RegularTest.php
/branches/0.8.1/Test/FS/File/PHP/Parser/TestClass.php
/branches/0.8.1/Test/FS/File/PermissionsTest.php
/branches/0.8.1/Test/FS/File/ReaderTest.php
/branches/0.8.1/Test/FS/File/RecursiveNameFilterTest.php
/branches/0.8.1/Test/FS/File/RecursiveRegexFilterTest.php
/branches/0.8.1/Test/FS/File/RegexFilterTest.php
/branches/0.8.1/Test/FS/File/StaticCacheTest.php
/branches/0.8.1/Test/FS/File/UnicoderTest.php
/branches/0.8.1/Test/FS/File/WriterTest.php
/branches/0.8.1/Test/FS/File/YAML/ReaderTest.php
/branches/0.8.1/Test/FS/File/YAML/WriterTest.php
/branches/0.8.1/Test/FS/Folder/EditorTest.php
/branches/0.8.1/Test/FS/Folder/IteratorTest.php
/branches/0.8.1/Test/FS/Folder/ListerTest.php
/branches/0.8.1/Test/FS/Folder/ReaderTest.php
/branches/0.8.1/Test/FS/Folder/RecursiveIteratorTest.php
/branches/0.8.1/Test/FS/Folder/RecursiveListerTest.php
/branches/0.8.1/Test/FS/Folder/RecursiveRegexFilterTest.php
/branches/0.8.1/Test/FS/Folder/RegexFilterTest.php
/branches/0.8.1/Test/FS/Folder/TestCase.php
/branches/0.8.1/Test/Net/FTP/ConnectionTest.php
/branches/0.8.1/Test/Net/Service/Definition/XmlReaderTest.php
/branches/0.8.1/Test/Net/Service/Definition/XmlWriterTest.php
/branches/0.8.1/Test/UI/Image/CreatorTest.php
/branches/0.8.1/Test/UI/Image/ErrorTest.php
/branches/0.8.1/Test/UI/Image/GaussBlurTest.php
/branches/0.8.1/Test/UI/Image/InverterTest.php
/branches/0.8.1/Test/UI/Image/MedianBlurTest.php
/branches/0.8.1/Test/UI/Image/PrinterTest.php
/branches/0.8.1/Test/UI/Image/ThumbnailCreatorTest.php
/branches/0.8.1/Test/XML/WDDX/FileReaderTest.php
/branches/0.8.1/Test/initLoaders.php

=======================================
--- /branches/0.8.1/Test/Math/Algebra/LabelMatrixTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/Algebra/LabelMatrixTest.php Thu May 28
07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_Algebra_LabelMatrix.
+ * TestUnit of Alg_Math_Algebra_LabelMatrix.
* @package Tests.math.algebra
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_Algebra_LabelMatrix.
+ * TestUnit of Alg_Math_Algebra_LabelMatrix.
* @package Tests.math.algebra
* @extends Test_Case
- * @uses Math_Algebra_LabelMatrix
+ * @uses Alg_Math_Algebra_LabelMatrix
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_Algebra_LabelMatrixTest extends Test_Case
+class Test_Alg_Math_Algebra_LabelMatrixTest extends Test_Case
{
/**
* Constructor.
@@ -36,7 +36,7 @@
{
$rows = array( "A1", "A2" );
$columns = array( "B1", "B2", "B3" );
- $this->matrix = new Math_Algebra_LabelMatrix( $rows, $columns );
+ $this->matrix = new Alg_Math_Algebra_LabelMatrix( $rows, $columns );
$this->matrix->setValue( "A1", "B1", 1 );
$this->matrix->setValue( "A1", "B2", 2 );
$this->matrix->setValue( "A1", "B3", 3 );
@@ -63,7 +63,7 @@
{
$rows = array( "A1" );
$columns = array( "B1", "B2", "B3" );
- $matrix = new Math_Algebra_LabelMatrix( $rows, $columns, 10 );
+ $matrix = new Alg_Math_Algebra_LabelMatrix( $rows, $columns, 10 );

$assertion = 1;
$creation = $matrix->getRowNumber();
@@ -90,7 +90,7 @@
public function testConstructException1()
{
$this->setExpectedException( 'InvalidArgumentException' );
- new Math_Algebra_LabelMatrix( array(), array( "a", "b", "c", "d", "e" )
);
+ new Alg_Math_Algebra_LabelMatrix( array(),
array( "a", "b", "c", "d", "e" ) );
}

/**
@@ -101,7 +101,7 @@
public function testConstructException2()
{
$this->setExpectedException( 'InvalidArgumentException' );
- new Math_Algebra_LabelMatrix( array( "a", "b", "c", "d", "e" ), array()
);
+ new Alg_Math_Algebra_LabelMatrix( array( "a", "b", "c", "d", "e" ),
array() );
}

/**
=======================================
--- /branches/0.8.1/Test/Math/Algebra/MatrixTest.php Sat May 23 06:59:40
2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/Algebra/MatrixTest.php Thu May 28
07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_Algebra_Matrix.
+ * TestUnit of Alg_Math_Algebra_Matrix.
* @package Tests.math.algebra
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_Algebra_Matrix.
+ * TestUnit of Alg_Math_Algebra_Matrix.
* @package Tests.math.algebra
* @extends Test_Case
- * @uses Math_Algebra_Matrix
+ * @uses Alg_Math_Algebra_Matrix
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_Algebra_MatrixTest extends Test_Case
+class Test_Alg_Math_Algebra_MatrixTest extends Test_Case
{
/**
* Constructor.
@@ -34,7 +34,7 @@
*/
public function setUp()
{
- $this->matrix = new Math_Algebra_Matrix( 2, 3 );
+ $this->matrix = new Alg_Math_Algebra_Matrix( 2, 3 );
$this->matrix->setValue( 0, 0, 1 );
$this->matrix->setValue( 0, 1, 2 );
$this->matrix->setValue( 0, 2, 3 );
@@ -59,7 +59,7 @@
*/
public function testConstruct()
{
- $matrix = new Math_Algebra_Matrix( 1, 3, 10 );
+ $matrix = new Alg_Math_Algebra_Matrix( 1, 3, 10 );

$assertion = 1;
$creation = $matrix->getRowNumber();
@@ -82,7 +82,7 @@
public function testConstructException1()
{
$this->setExpectedException( 'InvalidArgumentException' );
- new Math_Algebra_Matrix( 0, 10 );
+ new Alg_Math_Algebra_Matrix( 0, 10 );
}

/**
@@ -93,7 +93,7 @@
public function testConstructException2()
{
$this->setExpectedException( 'InvalidArgumentException' );
- new Math_Algebra_Matrix( 10, 0 );
+ new Alg_Math_Algebra_Matrix( 10, 0 );
}

/**
@@ -140,15 +140,15 @@
*/
public function testGetColumn()
{
- $assertion = new Math_Algebra_Vector( 1, 4 );
+ $assertion = new Alg_Math_Algebra_Vector( 1, 4 );
$creation = $this->matrix->getColumn( 0 );
$this->assertEquals( $assertion, $creation );

- $assertion = new Math_Algebra_Vector( 2, 5 );
+ $assertion = new Alg_Math_Algebra_Vector( 2, 5 );
$creation = $this->matrix->getColumn( 1 );
$this->assertEquals( $assertion, $creation );

- $assertion = new Math_Algebra_Vector( 3, 6 );
+ $assertion = new Alg_Math_Algebra_Vector( 3, 6 );
$creation = $this->matrix->getColumn( 2 );
$this->assertEquals( $assertion, $creation );
}
@@ -182,11 +182,11 @@
*/
public function testGetRow()
{
- $assertion = new Math_Algebra_Vector( 1, 2, 3 );
+ $assertion = new Alg_Math_Algebra_Vector( 1, 2, 3 );
$creation = $this->matrix->getRow( 0 );
$this->assertEquals( $assertion, $creation );

- $assertion = new Math_Algebra_Vector( 4, 5, 6 );
+ $assertion = new Alg_Math_Algebra_Vector( 4, 5, 6 );
$creation = $this->matrix->getRow( 1 );
$this->assertEquals( $assertion, $creation );
}
@@ -302,11 +302,11 @@
public function testTranspose()
{
$this->matrix->transpose();
- $assertion = new Math_Algebra_Vector( 1, 2, 3 );
+ $assertion = new Alg_Math_Algebra_Vector( 1, 2, 3 );
$creation = $this->matrix->getColumn( 0 );
$this->assertEquals( $assertion, $creation );

- $assertion = new Math_Algebra_Vector( 4, 5, 6 );
+ $assertion = new Alg_Math_Algebra_Vector( 4, 5, 6 );
$creation = $this->matrix->getColumn( 1 );
$this->assertEquals( $assertion, $creation );
}
@@ -320,11 +320,11 @@
{
$this->matrix->swapRows( 0, 1 );

- $assertion = new Math_Algebra_Vector( 1, 2, 3 );
+ $assertion = new Alg_Math_Algebra_Vector( 1, 2, 3 );
$creation = $this->matrix->getRow( 1 );
$this->assertEquals( $assertion, $creation );

- $assertion = new Math_Algebra_Vector( 4, 5, 6 ); ;
+ $assertion = new Alg_Math_Algebra_Vector( 4, 5, 6 ); ;
$creation = $this->matrix->getRow( 0 );
$this->assertEquals( $assertion, $creation );
}
@@ -360,21 +360,21 @@
{
$this->matrix->swapColumns( 0, 1 );

- $assertion = new Math_Algebra_Vector( 2, 1, 3 );
+ $assertion = new Alg_Math_Algebra_Vector( 2, 1, 3 );
$creation = $this->matrix->getRow( 0 );
$this->assertEquals( $assertion, $creation );

- $assertion = new Math_Algebra_Vector( 5, 4, 6 );
+ $assertion = new Alg_Math_Algebra_Vector( 5, 4, 6 );
$creation = $this->matrix->getRow( 1 );
$this->assertEquals( $assertion, $creation );

$this->matrix->swapColumns( 0, 2 );

- $assertion = new Math_Algebra_Vector( 3, 1, 2 );
+ $assertion = new Alg_Math_Algebra_Vector( 3, 1, 2 );
$creation = $this->matrix->getRow( 0 );
$this->assertEquals( $assertion, $creation );

- $assertion = new Math_Algebra_Vector( 6, 4, 5 );
+ $assertion = new Alg_Math_Algebra_Vector( 6, 4, 5 );
$creation = $this->matrix->getRow( 1 );
$this->assertEquals( $assertion, $creation );
}
=======================================
--- /branches/0.8.1/Test/Math/Algebra/VectorTest.php Sat May 23 06:59:40
2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/Algebra/VectorTest.php Thu May 28
07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_Algebra_Vector.
+ * TestUnit of Alg_Math_Algebra_Vector.
* @package Tests.math.algebra
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_Algebra_Vector.
+ * TestUnit of Alg_Math_Algebra_Vector.
* @package Tests.math.algebra
* @extends Test_Case
- * @uses Math_Algebra_Vector
+ * @uses Alg_Math_Algebra_Vector
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_Algebra_VectorTest extends Test_Case
+class Test_Alg_Math_Algebra_VectorTest extends Test_Case
{
/**
* Constructor.
@@ -34,7 +34,7 @@
*/
public function setUp()
{
- $this->vector = new Math_Algebra_Vector( 1.1, 2.2, -3 );
+ $this->vector = new Alg_Math_Algebra_Vector( 1.1, 2.2, -3 );
}

/**
@@ -53,12 +53,12 @@
*/
public function testConstruct()
{
- $vector = new Math_Algebra_Vector( 1, 2, 3 );
+ $vector = new Alg_Math_Algebra_Vector( 1, 2, 3 );
$assertion = array( 1, 2, 3 );
$creation = $vector->toArray();
$this->assertEquals( $assertion, $creation );

- $vector = new Math_Algebra_Vector( array( 1, 2, 3 ) );
+ $vector = new Alg_Math_Algebra_Vector( array( 1, 2, 3 ) );
$assertion = array( 1, 2, 3 );
$creation = $vector->toArray();
$this->assertEquals( $assertion, $creation );
@@ -72,7 +72,7 @@
public function testConstructException()
{
$this->setExpectedException( 'InvalidArgumentException' );
- new Math_Algebra_Vector();
+ new Alg_Math_Algebra_Vector();
}

/**
@@ -82,7 +82,7 @@
*/
public function testToString()
{
- $vector = new Math_Algebra_Vector( -1.5, -2.5 );
+ $vector = new Alg_Math_Algebra_Vector( -1.5, -2.5 );
$assertion = "(-1.5, -2.5)";
$creation = (string) $vector;
$this->assertEquals( $assertion, $creation );
=======================================
--- /branches/0.8.1/Test/Math/AverageTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/AverageTest.php Thu May 28 07:36:27 2015
UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_Average.
+ * TestUnit of Alg_Math_Average.
* @package Tests.math
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_Average.
+ * TestUnit of Alg_Math_Average.
* @package Tests.math
* @extends Test_Case
- * @uses Math_Average
+ * @uses Alg_Math_Average
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_AverageTest extends Test_Case
+class Test_Alg_Math_AverageTest extends Test_Case
{
/**
* Constructor.
@@ -53,19 +53,19 @@
public function testArithmetic()
{
$assertion = 2;
- $creation = Math_Average::arithmetic( array( 1, 2, 3 ) );
+ $creation = Alg_Math_Average::arithmetic( array( 1, 2, 3 ) );
$this->assertEquals( $assertion, $creation );

$assertion = 2.5;
- $creation = Math_Average::arithmetic( array( 1, 2, 3, 4 ), 1 );
+ $creation = Alg_Math_Average::arithmetic( array( 1, 2, 3, 4 ), 1 );
$this->assertEquals( $assertion, $creation );

$assertion = 10;
- $creation = Math_Average::arithmetic( array( 5, 5, 15, 15, 10, 0, 20 ) );
+ $creation = Alg_Math_Average::arithmetic( array( 5, 5, 15, 15, 10, 0, 20
) );
$this->assertEquals( $assertion, $creation );

$assertion = round( 3 / 2, 4 );
- $creation = Math_Average::arithmetic( array( 1, 2 ), 4 );
+ $creation = Alg_Math_Average::arithmetic( array( 1, 2 ), 4 );
$this->assertEquals( $assertion, $creation );
}

@@ -77,15 +77,15 @@
public function testGeometric()
{
$assertion = 2;
- $creation = Math_Average::geometric( array( 1, 2, 3 ) );
+ $creation = Alg_Math_Average::geometric( array( 1, 2, 3 ) );
$this->assertEquals( $assertion, $creation );

$assertion = 2.2;
- $creation = Math_Average::geometric( array( 1, 2, 3, 4 ), 1 );
+ $creation = Alg_Math_Average::geometric( array( 1, 2, 3, 4 ), 1 );
$this->assertEquals( $assertion, $creation );

$assertion = 13;
- $creation = Math_Average::geometric( array( 10, 16.9 ) );
+ $creation = Alg_Math_Average::geometric( array( 10, 16.9 ) );
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/Math/CompactIntervalTest.php Sat May 23 06:59:40
2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/CompactIntervalTest.php Thu May 28
07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_CompactInterval.
+ * TestUnit of Alg_Math_CompactInterval.
* @package Tests.math
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_CompactInterval.
+ * TestUnit of Alg_Math_CompactInterval.
* @package Tests.math
* @extends Test_Case
- * @uses Math_CompactInterval
+ * @uses Alg_Math_CompactInterval
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_CompactIntervalTest extends Test_Case
+class Test_Alg_Math_CompactIntervalTest extends Test_Case
{
/**
* Constructor.
@@ -25,7 +25,7 @@
*/
public function __construct()
{
- $this->interval = new Math_CompactInterval( 3, 9 );
+ $this->interval = new Alg_Math_CompactInterval( 3, 9 );
}

/**
@@ -53,7 +53,7 @@
*/
public function testConstruct()
{
- $interval = new Math_CompactInterval( 1, 2 );
+ $interval = new Alg_Math_CompactInterval( 1, 2 );
$assertion = "I[1;2]";
$creation = (string) $interval;
$this->assertEquals( $assertion, $creation );
=======================================
--- /branches/0.8.1/Test/Math/FactorialTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/FactorialTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_Factorial.
+ * TestUnit of Alg_Math_Factorial.
* @package Tests.math
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_Factorial.
+ * TestUnit of Alg_Math_Factorial.
* @package Tests.math
* @extends Test_Case
- * @uses Math_Factorial
+ * @uses Alg_Math_Factorial
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_FactorialTest extends Test_Case
+class Test_Alg_Math_FactorialTest extends Test_Case
{
/**
* Constructor.
@@ -53,7 +53,7 @@
public function testCalculateException1()
{
$this->setExpectedException( 'InvalidArgumentException' );
- Math_Factorial::calculate( -1 );
+ Alg_Math_Factorial::calculate( -1 );
}

/**
@@ -64,7 +64,7 @@
public function testCalculateException2()
{
$this->setExpectedException( 'InvalidArgumentException' );
- Math_Factorial::calculate( "no_integer" );
+ Alg_Math_Factorial::calculate( "no_integer" );
}

/**
@@ -75,15 +75,15 @@
public function testCalculate()
{
$assertion = 1;
- $creation = Math_Factorial::calculate( 1 );
+ $creation = Alg_Math_Factorial::calculate( 1 );
$this->assertEquals( $assertion, $creation );

$assertion = 6;
- $creation = Math_Factorial::calculate( 3 );
+ $creation = Alg_Math_Factorial::calculate( 3 );
$this->assertEquals( $assertion, $creation );

$assertion = 120;
- $creation = Math_Factorial::calculate( 5 );
+ $creation = Alg_Math_Factorial::calculate( 5 );
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/Math/Finance/CompoundInterestTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/Finance/CompoundInterestTest.php Thu May
28 07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_Finance_CompoundInterest.
+ * TestUnit of Alg_Math_Finance_CompoundInterest.
* @package Tests.math.finance
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_Finance_CompoundInterest.
+ * TestUnit of Alg_Math_Finance_CompoundInterest.
* @package Tests.math.finance
* @extends Test_Case
- * @uses Math_Finance_CompoundInterest
+ * @uses Alg_Math_Finance_CompoundInterest
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_Finance_CompoundInterestTest extends Test_Case
+class Test_Alg_Math_Finance_CompoundInterestTest extends Test_Case
{
/**
* Constructor.
@@ -25,7 +25,7 @@
*/
public function __construct()
{
- $this->calc = new Math_Finance_CompoundInterest();
+ $this->calc = new Alg_Math_Finance_CompoundInterest();
}

/**
@@ -54,15 +54,15 @@
public function testCalculateFutureAmount()
{
$assertion = 1100;
- $creation = Math_Finance_CompoundInterest::calculateFutureAmount( 1000,
10, 1 );
+ $creation = Alg_Math_Finance_CompoundInterest::calculateFutureAmount(
1000, 10, 1 );
$this->assertEquals( $assertion, $creation );

$assertion = 1210;
- $creation = (int) Math_Finance_CompoundInterest::calculateFutureAmount(
1000, 10, 2 );
+ $creation = (int)
Alg_Math_Finance_CompoundInterest::calculateFutureAmount( 1000, 10, 2 );
$this->assertEquals( $assertion, $creation );

$assertion = 1331;
- $creation = (int) Math_Finance_CompoundInterest::calculateFutureAmount(
1000, 10, 3 );
+ $creation = (int)
Alg_Math_Finance_CompoundInterest::calculateFutureAmount( 1000, 10, 3 );
$this->assertEquals( $assertion, $creation );
}

@@ -74,7 +74,7 @@
public function testCalculateFutureAmountException()
{
$this->setExpectedException( 'InvalidArgumentException' );
- Math_Finance_CompoundInterest::calculateFutureAmount( 1000, 1, 0 );
+ Alg_Math_Finance_CompoundInterest::calculateFutureAmount( 1000, 1, 0 );
}

/**
@@ -85,15 +85,15 @@
public function testCalculatePresentAmount()
{
$assertion = 1000;
- $creation = round(
Math_Finance_CompoundInterest::calculatePresentAmount( 1100, 10, 1 ) );
+ $creation = round(
Alg_Math_Finance_CompoundInterest::calculatePresentAmount( 1100, 10, 1 ) );
$this->assertEquals( $assertion, $creation );

$assertion = 1000;
- $creation = round(
Math_Finance_CompoundInterest::calculatePresentAmount( 1210, 10, 2 ) );
+ $creation = round(
Alg_Math_Finance_CompoundInterest::calculatePresentAmount( 1210, 10, 2 ) );
$this->assertEquals( $assertion, $creation );

$assertion = 1000;
- $creation = round(
Math_Finance_CompoundInterest::calculatePresentAmount( 1331, 10, 3 ) );
+ $creation = round(
Alg_Math_Finance_CompoundInterest::calculatePresentAmount( 1331, 10, 3 ) );
$this->assertEquals( $assertion, $creation );
}

@@ -105,7 +105,7 @@
public function testCalculatePresentAmountException()
{
$this->setExpectedException( 'InvalidArgumentException' );
- Math_Finance_CompoundInterest::calculatePresentAmount( 1000, 10, 0 );
+ Alg_Math_Finance_CompoundInterest::calculatePresentAmount( 1000, 10, 0 );
}

/**
@@ -116,15 +116,15 @@
public function testCalculateInterest()
{
$assertion = 10;
- $creation = round( Math_Finance_CompoundInterest::calculateInterest(
1000, 1100, 1 ) );
+ $creation = round( Alg_Math_Finance_CompoundInterest::calculateInterest(
1000, 1100, 1 ) );
$this->assertEquals( $assertion, $creation );

$assertion = 10;
- $creation = round( Math_Finance_CompoundInterest::calculateInterest(
1000, 1210, 2 ) );
+ $creation = round( Alg_Math_Finance_CompoundInterest::calculateInterest(
1000, 1210, 2 ) );
$this->assertEquals( $assertion, $creation );

$assertion = 10;
- $creation = round( Math_Finance_CompoundInterest::calculateInterest(
1000, 1331, 3 ) );
+ $creation = round( Alg_Math_Finance_CompoundInterest::calculateInterest(
1000, 1331, 3 ) );
$this->assertEquals( $assertion, $creation );
}

@@ -136,7 +136,7 @@
public function testCalculateInterestException()
{
$this->setExpectedException( 'InvalidArgumentException' );
- Math_Finance_CompoundInterest::calculateInterest( 1000, 1000, 0 );
+ Alg_Math_Finance_CompoundInterest::calculateInterest( 1000, 1000, 0 );
}

/**
=======================================
--- /branches/0.8.1/Test/Math/FormulaProductTest.php Sat May 23 06:59:40
2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/FormulaProductTest.php Thu May 28
07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_FormulaProduct.
+ * TestUnit of Alg_Math_FormulaProduct.
* @package Tests.math
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_FormulaProduct.
+ * TestUnit of Alg_Math_FormulaProduct.
* @package Tests.math
* @extends Test_Case
- * @uses Math_FormulaProduct
+ * @uses Alg_Math_FormulaProduct
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_FormulaProductTest extends Test_Case
+class Test_Alg_Math_FormulaProductTest extends Test_Case
{
/**
* Constructor.
@@ -53,7 +53,7 @@
public function testConstructException1()
{
$this->setExpectedException( 'InvalidArgumentException' );
- new Math_FormulaProduct( "no_object", "no_object" );
+ new Alg_Math_FormulaProduct( "no_object", "no_object" );
}

/**
@@ -64,7 +64,7 @@
public function testConstructException2()
{
$this->setExpectedException( 'InvalidArgumentException' );
- new Math_FormulaProduct( new Math_Formula( "x", "x" ), "no_object" );
+ new Alg_Math_FormulaProduct( new Alg_Math_Formula( "x", "x"
), "no_object" );
}

/**
@@ -74,16 +74,16 @@
*/
public function testCalculate()
{
- $interval = new Math_CompactInterval( 1, 4 );
- $formula = new Math_Formula( "x", "x" );
- $product = new Math_FormulaProduct( $formula, $interval );
+ $interval = new Alg_Math_CompactInterval( 1, 4 );
+ $formula = new Alg_Math_Formula( "x", "x" );
+ $product = new Alg_Math_FormulaProduct( $formula, $interval );
$creation = $product->calculate();
$assertion = 24;
$this->assertEquals( $assertion, $creation );

- $interval = new Math_CompactInterval( 1, 4 );
- $formula = new Math_Formula( "2*x*y", array( "x", "y" ) );
- $product = new Math_FormulaProduct( $formula, $interval );
+ $interval = new Alg_Math_CompactInterval( 1, 4 );
+ $formula = new Alg_Math_Formula( "2*x*y", array( "x", "y" ) );
+ $product = new Alg_Math_FormulaProduct( $formula, $interval );
$creation = $product->calculate( 3 );
$assertion = 31104;
$this->assertEquals( $assertion, $creation );
=======================================
--- /branches/0.8.1/Test/Math/FormulaSumTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/Alg/Math/FormulaSumTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_FormulaSum.
+ * TestUnit of Alg_Math_FormulaSum.
* @package Tests.math
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_FormulaSum.
+ * TestUnit of Alg_Math_FormulaSum.
* @package Tests.math
* @extends Test_Case
- * @uses Math_FormulaSum
+ * @uses Alg_Math_FormulaSum
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_FormulaSumTest extends Test_Case
+class Test_Alg_Math_FormulaSumTest extends Test_Case
{
/**
* Constructor.
@@ -53,7 +53,7 @@
public function testConstructException1()
{
$this->setExpectedException( 'InvalidArgumentException' );
- new Math_FormulaSum( "no_object", "no_object" );
+ new Alg_Math_FormulaSum( "no_object", "no_object" );
}

/**
@@ -64,7 +64,7 @@
public function testConstructException2()
{
$this->setExpectedException( 'InvalidArgumentException' );
- new Math_FormulaSum( new Math_Formula( "x", "x" ), "no_object" );
+ new Alg_Math_FormulaSum( new Alg_Math_Formula( "x", "x" ), "no_object" );
}

/**
@@ -74,16 +74,16 @@
*/
public function testCalculate()
{
- $interval = new Math_CompactInterval( 1, 4 );
- $formula = new Math_Formula( "x", "x" );
- $sum = new Math_FormulaSum( $formula, $interval );
+ $interval = new Alg_Math_CompactInterval( 1, 4 );
+ $formula = new Alg_Math_Formula( "x", "x" );
+ $sum = new Alg_Math_FormulaSum( $formula, $interval );
$creation = $sum->calculate();
$assertion = 10;
$this->assertEquals( $assertion, $creation );

- $interval = new Math_CompactInterval( 1, 4 );
- $formula = new Math_Formula( "2*x*y", array( "x", "y" ) );
- $sum = new Math_FormulaSum( $formula, $interval );
+ $interval = new Alg_Math_CompactInterval( 1, 4 );
+ $formula = new Alg_Math_Formula( "2*x*y", array( "x", "y" ) );
+ $sum = new Alg_Math_FormulaSum( $formula, $interval );
$creation = $sum->calculate( 3 );
$assertion = 60;
$this->assertEquals( $assertion, $creation );
=======================================
--- /branches/0.8.1/Test/Math/FormulaTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/FormulaTest.php Thu May 28 07:36:27 2015
UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_Formula.
+ * TestUnit of Alg_Math_Formula.
* @package Tests.math
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_Formula.
+ * TestUnit of Alg_Math_Formula.
* @package Tests.math
* @extends Test_Case
- * @uses Math_Formula
+ * @uses Alg_Math_Formula
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_FormulaTest extends Test_Case
+class Test_Alg_Math_FormulaTest extends Test_Case
{
/**
* Constructor.
@@ -25,7 +25,7 @@
*/
public function __construct()
{
- $this->formula = new Math_Formula( "x * y", array( "x", "y" ) );
+ $this->formula = new Alg_Math_Formula( "x * y", array( "x", "y" ) );
}

/**
@@ -53,7 +53,7 @@
*/
public function testConstruct()
{
- $formula = new Math_Formula( "x*y", array( "x", "y" ) );
+ $formula = new Alg_Math_Formula( "x*y", array( "x", "y" ) );

$assertion = "x*y";
$creation = $formula->getExpression();
@@ -72,7 +72,7 @@
public function testConstructException()
{
$this->setExpectedException( 'InvalidArgumentException' );
- $creation = new Math_Formula( "x", array( "x", "x" ) );
+ $creation = new Alg_Math_Formula( "x", array( "x", "x" ) );
}

/**
=======================================
--- /branches/0.8.1/Test/Math/PrimeTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/Alg/Math/PrimeTest.php Thu May 28 07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Math_Prime.
+ * TestUnit of Alg_Math_Prime.
* @package Tests.math
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Math_Prime.
+ * TestUnit of Alg_Math_Prime.
* @package Tests.math
* @extends Test_Case
- * @uses Math_Prime
+ * @uses Alg_Math_Prime
* @author Christian Würker <christia...@ceusmedia.de>
* @since 17.06.2008
* @version 0.1
*/
-class Test_Math_PrimeTest extends Test_Case
+class Test_Alg_Math_PrimeTest extends Test_Case
{
/**
* Tests Method 'getPrimes'.
@@ -26,11 +26,11 @@
public function testGetPrimes()
{
$assertion = array( 2, 3, 5, 7 );
- $creation = Math_Prime::getPrimes( 10 );
+ $creation = Alg_Math_Prime::getPrimes( 10 );
$this->assertEquals( $assertion, $creation );

$assertion = array( 2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43,
47 );
- $creation = Math_Prime::getPrimes( 50 );
+ $creation = Alg_Math_Prime::getPrimes( 50 );
$this->assertEquals( $assertion, $creation );
}

@@ -42,27 +42,27 @@
public function testIsPrime()
{
$assertion = FALSE;
- $creation = Math_Prime::isPrime( 1 );
+ $creation = Alg_Math_Prime::isPrime( 1 );
$this->assertEquals( $assertion, $creation );

$assertion = TRUE;
- $creation = Math_Prime::isPrime( 2 );
+ $creation = Alg_Math_Prime::isPrime( 2 );
$this->assertEquals( $assertion, $creation );

$assertion = TRUE;
- $creation = Math_Prime::isPrime( 3 );
+ $creation = Alg_Math_Prime::isPrime( 3 );
$this->assertEquals( $assertion, $creation );

$assertion = FALSE;
- $creation = Math_Prime::isPrime( 4 );
+ $creation = Alg_Math_Prime::isPrime( 4 );
$this->assertEquals( $assertion, $creation );

$assertion = FALSE;
- $creation = Math_Prime::isPrime( 1001 );
+ $creation = Alg_Math_Prime::isPrime( 1001 );
$this->assertEquals( $assertion, $creation );

$assertion = TRUE;
- $creation = Math_Prime::isPrime( 1009 );
+ $creation = Alg_Math_Prime::isPrime( 1009 );
$this->assertEquals( $assertion, $creation );
}

@@ -74,19 +74,19 @@
public function testGetPrimeFactors()
{
$assertion = array( 2 );
- $creation = Math_Prime::getPrimeFactors( 2 );
+ $creation = Alg_Math_Prime::getPrimeFactors( 2 );
$this->assertEquals( $assertion, $creation );

$assertion = array( 2, 2 );
- $creation = Math_Prime::getPrimeFactors( 4 );
+ $creation = Alg_Math_Prime::getPrimeFactors( 4 );
$this->assertEquals( $assertion, $creation );

$assertion = array( 7, 11, 13 );
- $creation = Math_Prime::getPrimeFactors( 1001 );
+ $creation = Alg_Math_Prime::getPrimeFactors( 1001 );
$this->assertEquals( $assertion, $creation );

$assertion = array( 2, 3, 167 );
- $creation = Math_Prime::getPrimeFactors( 1002 );
+ $creation = Alg_Math_Prime::getPrimeFactors( 1002 );
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/Console/Command/ArgumentParserTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/CLI/Command/ArgumentParserTest.php Thu May 28
07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Console_Command_ArgumentParser.
+ * TestUnit of CLI_Command_ArgumentParser.
* @package Tests.
* @author Christian Würker <christia...@ceusmedia.de>
* @since 24.10.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Console_Command_ArgumentParser.
+ * TestUnit of CLI_Command_ArgumentParser.
* @package Tests.
* @extends Test_Case
- * @uses Console_Command_ArgumentParser
+ * @uses CLI_Command_ArgumentParser
* @author Christian Würker <christia...@ceusmedia.de>
* @since 24.10.2008
* @version 0.1
*/
-class Test_Console_Command_ArgumentParserTest extends Test_Case
+class Test_CLI_Command_ArgumentParserTest extends Test_Case
{
/**
* Constructor.
@@ -34,7 +34,7 @@
*/
public function setUp()
{
- $this->parser = new Test_Console_Command_ArgumentParserInstance();
+ $this->parser = new Test_CLI_Command_ArgumentParserInstance();
}

/**
@@ -127,7 +127,7 @@
);
$string = "-a xyz -beta 123 -f Argument1 Argument2";

- $parser = new Console_Command_ArgumentParser();
+ $parser = new CLI_Command_ArgumentParser();
$parser->setNumberOfMandatoryArguments( 2 );
$parser->setPossibleOptions( $options );
$parser->setShortcuts( $shortcuts );
@@ -261,7 +261,7 @@
$this->assertEquals( $assertion, $creation );
}
}
-class Test_Console_Command_ArgumentParserInstance extends
Console_Command_ArgumentParser
+class Test_CLI_Command_ArgumentParserInstance extends
CLI_Command_ArgumentParser
{
public function getProtectedVar( $varName )
{
=======================================
--- /branches/0.8.1/Test/Console/Command/ProgramTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/CLI/Command/ProgramTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Console_Command_Program.
+ * TestUnit of CLI_Command_Program.
* @package Tests.console.command
* @author Christian Würker <christia...@ceusmedia.de>
* @since 12.01.2009
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Console_Command_Program.
+ * TestUnit of CLI_Command_Program.
* @package Tests.console.command
* @extends Test_Case
- * @uses Console_Command_Program
+ * @uses CLI_Command_Program
* @author Christian Würker <christia...@ceusmedia.de>
* @since 12.01.2009
* @version 0.1
*/
-class Test_Console_Command_ProgramTest extends Test_Case
+class Test_CLI_Command_ProgramTest extends Test_Case
{
/**
* Constructor.
@@ -61,13 +61,13 @@
*/
public function testRun()
{
- $program = new Test_Console_Command_TestProgram;
+ $program = new Test_CLI_Command_TestProgram;
$assertion = 2;
$creation = $program->run( "arg1" );
$this->assertEquals( $assertion, $creation );
}
}
-class Test_Console_Command_TestProgram extends Console_Command_Program
+class Test_CLI_Command_TestProgram extends CLI_Command_Program
{
public $testOptions = array(
'user' => "@[a-z]@i",
=======================================
--- /branches/0.8.1/Test/Database/BaseConnectionTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/DB/BaseConnectionTest.php Thu May 28 07:36:27 2015
UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_BaseConnection.
+ * TestUnit of DB_BaseConnection.
* @package Tests.database
* @author Christian Würker <christia...@ceusmedia.de>
* @since 04.05.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_BaseConnection.
+ * TestUnit of DB_BaseConnection.
* @package Tests.database
* @extends Test_Case
- * @uses Database_BaseConnection
+ * @uses DB_BaseConnection
* @author Christian Würker <christia...@ceusmedia.de>
* @since 04.05.2008
* @version 0.1
*/
-class Test_Database_BaseConnectionTest extends Test_Case
+class Test_DB_BaseConnectionTest extends Test_Case
{
/**
* Constructor.
@@ -34,7 +34,7 @@
*/
public function setUp()
{
- $this->connection = new Test_Database_BaseConnectionInstance();
+ $this->connection = new Test_DB_BaseConnectionInstance();
}

/**
@@ -53,7 +53,7 @@
*/
public function testConstruct()
{
- $connection = new Test_Database_BaseConnectionInstance( "test" );
+ $connection = new Test_DB_BaseConnectionInstance( "test" );

$assertion = "test";
$creation = $connection->getProtectedVar( 'logFile' );
@@ -73,7 +73,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_BaseConnection::connect();
+ $creation = DB_BaseConnection::connect();
$this->assertEquals( $assertion, $creation );
}

@@ -130,7 +130,7 @@
$this->assertEquals( $assertion, $creation );
}
}
-class Test_Database_BaseConnectionInstance extends Database_BaseConnection
+class Test_DB_BaseConnectionInstance extends DB_BaseConnection
{
function getProtectedVar( $key )
{
=======================================
--- /branches/0.8.1/Test/Database/PDO/ConnectionTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/DB/PDO/ConnectionTest.php Thu May 28 07:36:27 2015
UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_PDO_Connection.
+ * TestUnit of DB_PDO_Connection.
* @package Tests.database.pdo
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.07.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_PDO_Connection.
+ * TestUnit of DB_PDO_Connection.
* @package Tests.database.pdo
* @extends Test_Case
- * @uses Database_PDO_Connection
+ * @uses DB_PDO_Connection
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.07.2008
* @version 0.1
*/
-class Test_Database_PDO_ConnectionTest extends Test_Case
+class Test_DB_PDO_ConnectionTest extends Test_Case
{
/**
* Constructor.
@@ -46,7 +46,7 @@
$this->markTestSkipped( "PDO driver for MySQL not supported" );
$dsn = "mysql:host=".$this->host.";dbname=".$this->database;
$options = array();
- $this->connection = new Database_PDO_Connection( $dsn, $this->username,
$this->password, $options );
+ $this->connection = new DB_PDO_Connection( $dsn, $this->username,
$this->password, $options );
$this->connection->setAttribute( PDO::ATTR_CASE, PDO::CASE_NATURAL );
$this->connection->setAttribute( PDO::MYSQL_ATTR_USE_BUFFERED_QUERY,
TRUE );
$this->connection->setErrorLogFile( $this->errorLog );
=======================================
--- /branches/0.8.1/Test/Database/PDO/TableReaderTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/DB/PDO/TableReaderTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_PDO_TableReader.
+ * TestUnit of DB_PDO_TableReader.
* @package Tests.database.pdo
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.07.2008
@@ -8,16 +8,16 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_PDO_TableReader.
+ * TestUnit of DB_PDO_TableReader.
* @package Tests.database.pdo
* @extends Test_Case
- * @uses Database_PDO_Connection
- * @uses Database_PDO_TableReader
+ * @uses DB_PDO_Connection
+ * @uses DB_PDO_TableReader
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.07.2008
* @version 0.1
*/
-class Test_Database_PDO_TableReaderTest extends Test_Case
+class Test_DB_PDO_TableReaderTest extends Test_Case
{
/**
* Constructor.
@@ -35,10 +35,11 @@
$this->errorLog = $this->path."errors.log";
$this->queryLog = $this->path."queries.log";

- $this->dsn = "mysql:host=".$this->host.";dbname=".$this->database;
-
+ $this->dsn = "mysql:host=".$this->host.";dbname=".$this->database;
+ $this->options = array();
+
$this->tableName = "transactions";
- $this->columns = array(
+ $this->columns = array(
'id',
'topic',
'label',
@@ -64,7 +65,7 @@
$this->markTestSkipped( "Support for MySQL is missing" );

$options = array();
- $this->connection = new Database_PDO_Connection( $this->dsn,
$this->username, $this->password, $options );
+ $this->connection = new DB_PDO_Connection( $this->dsn, $this->username,
$this->password, $this->options );
$this->connection->setAttribute( PDO::ATTR_CASE, PDO::CASE_NATURAL );
$this->connection->setAttribute( PDO::MYSQL_ATTR_USE_BUFFERED_QUERY,
TRUE );
$this->connection->setErrorLogFile( $this->errorLog );
@@ -77,7 +78,7 @@
if( trim( $part ) )
mysql_query( $part ) or die( mysql_error() );

- $this->reader = new Database_PDO_TableReader( $this->connection,
$this->tableName, $this->columns, $this->primaryKey );
+ $this->reader = new DB_PDO_TableReader( $this->connection,
$this->tableName, $this->columns, $this->primaryKey );
$this->reader->setIndices( $this->indices );
}

@@ -101,7 +102,7 @@
*/
public function testConstruct1()
{
- $reader = new Database_PDO_TableReader( $this->connection, "table",
array( 'col1', 'col2' ), 'col2', 1 );
+ $reader = new DB_PDO_TableReader( $this->connection, "table",
array( 'col1', 'col2' ), 'col2', 1 );

$assertion = 'table';
$creation = $reader->getTableName();
@@ -127,7 +128,7 @@
*/
public function testConstruct2()
{
- $reader = new Database_PDO_TableReader( $this->connection,
$this->tableName, $this->columns, $this->primaryKey, 1 );
+ $reader = new DB_PDO_TableReader( $this->connection, $this->tableName,
$this->columns, $this->primaryKey, 1 );

$assertion = array( 'id' => 1 );
$creation = array_slice( $reader->get(), 0, 1 );
=======================================
--- /branches/0.8.1/Test/Database/PDO/TableWriterTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/DB/PDO/TableWriterTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_PDO_TableWriter.
+ * TestUnit of DB_PDO_TableWriter.
* @package Tests.{classPackage}
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
@@ -8,16 +8,16 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_PDO_TableWriter.
+ * TestUnit of DB_PDO_TableWriter.
* @package Tests.{classPackage}
* @extends Test_Case
- * @uses Database_PDO_Connection
- * @uses Database_PDO_TableWriter
+ * @uses DB_PDO_Connection
+ * @uses DB_PDO_TableWriter
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
* @version 0.1
*/
-class Test_Database_PDO_TableWriterTest extends Test_Case
+class Test_DB_PDO_TableWriterTest extends Test_Case
{
/**
* Constructor.
@@ -34,12 +34,12 @@
$this->path = dirname( __FILE__ )."/";
$this->errorLog = $this->path."errors.log";
$this->queryLog = $this->path."queries.log";
- $options = array();

- $this->dsn = "mysql:host=".$this->host.";dbname=".$this->database;
+ $this->dsn = "mysql:host=".$this->host.";dbname=".$this->database;
+ $this->options = array();

$this->tableName = "transactions";
- $this->columns = array(
+ $this->columns = array(
'id',
'topic',
'label',
@@ -64,7 +64,7 @@
if( !extension_loaded( 'mysql' ) )
$this->markTestSkipped( "Support for MySQL is missing" );

- $this->connection = new Database_PDO_Connection( $this->dsn,
$this->username, $this->password, $options );
+ $this->connection = new DB_PDO_Connection( $this->dsn, $this->username,
$this->password, $this->options );
$this->connection->setAttribute( PDO::ATTR_CASE, PDO::CASE_NATURAL );
$this->connection->setAttribute( PDO::MYSQL_ATTR_USE_BUFFERED_QUERY,
TRUE );
$this->connection->setErrorLogFile( $this->errorLog );
@@ -77,7 +77,7 @@
if( trim( $part ) )
mysql_query( $part ) or die( mysql_error() );

- $this->writer = new Database_PDO_TableWriter( $this->connection,
$this->tableName, $this->columns, $this->primaryKey );
+ $this->writer = new DB_PDO_TableWriter( $this->connection,
$this->tableName, $this->columns, $this->primaryKey );
$this->writer->setIndices( $this->indices );
}

=======================================
--- /branches/0.8.1/Test/Database/ResultTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/DB/ResultTest.php Thu May 28 07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_Result.
+ * TestUnit of DB_Result.
* @package Tests.database
* @author Christian Würker <christia...@ceusmedia.de>
* @since 15.05.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_Result.
+ * TestUnit of DB_Result.
* @package Tests.database
* @extends Test_Case
- * @uses Database_Result
+ * @uses DB_Result
* @author Christian Würker <christia...@ceusmedia.de>
* @since 15.05.2008
* @version 0.1
*/
-class Test_Database_ResultTest extends Test_Case
+class Test_DB_ResultTest extends Test_Case
{
/**
* Constructor.
@@ -54,7 +54,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::__construct();
+ $creation = DB_Result::__construct();
$this->assertEquals( $assertion, $creation );
}

@@ -67,7 +67,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::count();
+ $creation = DB_Result::count();
$this->assertEquals( $assertion, $creation );
}

@@ -80,7 +80,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::current();
+ $creation = DB_Result::current();
$this->assertEquals( $assertion, $creation );
}

@@ -93,7 +93,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::fetchArray();
+ $creation = DB_Result::fetchArray();
$this->assertEquals( $assertion, $creation );
}

@@ -106,7 +106,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::fetchNextArray();
+ $creation = DB_Result::fetchNextArray();
$this->assertEquals( $assertion, $creation );
}

@@ -119,7 +119,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::fetchNextObject();
+ $creation = DB_Result::fetchNextObject();
$this->assertEquals( $assertion, $creation );
}

@@ -132,7 +132,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::fetchNextRow();
+ $creation = DB_Result::fetchNextRow();
$this->assertEquals( $assertion, $creation );
}

@@ -145,7 +145,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::fetchObject();
+ $creation = DB_Result::fetchObject();
$this->assertEquals( $assertion, $creation );
}

@@ -158,7 +158,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::fetchRow();
+ $creation = DB_Result::fetchRow();
$this->assertEquals( $assertion, $creation );
}

@@ -171,7 +171,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::key();
+ $creation = DB_Result::key();
$this->assertEquals( $assertion, $creation );
}

@@ -184,7 +184,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::next();
+ $creation = DB_Result::next();
$this->assertEquals( $assertion, $creation );
}

@@ -197,7 +197,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::recordCount();
+ $creation = DB_Result::recordCount();
$this->assertEquals( $assertion, $creation );
}

@@ -210,7 +210,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::rewind();
+ $creation = DB_Result::rewind();
$this->assertEquals( $assertion, $creation );
}

@@ -223,7 +223,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Result::valid();
+ $creation = DB_Result::valid();
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/Database/RowTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/DB/RowTest.php Thu May 28 07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_Row.
+ * TestUnit of DB_Row.
* @package Tests.database
* @author Christian Würker <christia...@ceusmedia.de>
* @since 15.05.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_Row.
+ * TestUnit of DB_Row.
* @package Tests.database
* @extends Test_Case
- * @uses Database_Row
+ * @uses DB_Row
* @author Christian Würker <christia...@ceusmedia.de>
* @since 15.05.2008
* @version 0.1
*/
-class Test_Database_RowTest extends Test_Case
+class Test_DB_RowTest extends Test_Case
{
/**
* Constructor.
@@ -54,7 +54,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::getColCount();
+ $creation = DB_Row::getColCount();
$this->assertEquals( $assertion, $creation );
}

@@ -67,7 +67,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::getKeys();
+ $creation = DB_Row::getKeys();
$this->assertEquals( $assertion, $creation );
}

@@ -80,7 +80,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::getPairs();
+ $creation = DB_Row::getPairs();
$this->assertEquals( $assertion, $creation );
}

@@ -93,7 +93,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::getValue();
+ $creation = DB_Row::getValue();
$this->assertEquals( $assertion, $creation );
}

@@ -106,7 +106,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::getValues();
+ $creation = DB_Row::getValues();
$this->assertEquals( $assertion, $creation );
}

@@ -119,7 +119,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::count();
+ $creation = DB_Row::count();
$this->assertEquals( $assertion, $creation );
}

@@ -132,7 +132,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::current();
+ $creation = DB_Row::current();
$this->assertEquals( $assertion, $creation );
}

@@ -145,7 +145,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::key();
+ $creation = DB_Row::key();
$this->assertEquals( $assertion, $creation );
}

@@ -158,7 +158,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::next();
+ $creation = DB_Row::next();
$this->assertEquals( $assertion, $creation );
}

@@ -171,7 +171,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::rewind();
+ $creation = DB_Row::rewind();
$this->assertEquals( $assertion, $creation );
}

@@ -184,7 +184,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = Database_Row::valid();
+ $creation = DB_Row::valid();
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/Database/StatementBuilderTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/DB/StatementBuilderTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_StatementBuilder.
+ * TestUnit of DB_StatementBuilder.
* @package Tests.database
* @author Christian Würker <christia...@ceusmedia.de>
* @since 04.05.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_StatementBuilder.
+ * TestUnit of DB_StatementBuilder.
* @package Tests.database
* @extends Test_Case
- * @uses Database_StatementBuilder
+ * @uses DB_StatementBuilder
* @author Christian Würker <christia...@ceusmedia.de>
* @since 04.05.2008
* @version 0.1
*/
-class Test_Database_StatementBuilderTest extends Test_Case
+class Test_DB_StatementBuilderTest extends Test_Case
{
/**
* Setup for every Test.
@@ -25,7 +25,7 @@
*/
public function setUp()
{
- $this->builder = new Test_Database_StatementBuilderInstance( "prefix_" );
+ $this->builder = new Test_DB_StatementBuilderInstance( "prefix_" );
}

/**
@@ -40,7 +40,7 @@
$tables = array( "table1 as t1", "table2 as t2" );
$conditions = array( "t1.key1=t2.key2", "field1>1" );
$groupings = array( "key1", "key3" );
- $builder = new Test_Database_StatementBuilderInstance( $prefix, $keys,
$tables, $conditions, $groupings );
+ $builder = new Test_DB_StatementBuilderInstance( $prefix, $keys,
$tables, $conditions, $groupings );

$assertion = $prefix;
$creation = $builder->getProtectedVar( 'prefix' );
@@ -432,7 +432,7 @@
public function testGetPrefix()
{
$prefix = "new_prefix_";
- $builder = new Database_StatementBuilder( $prefix );
+ $builder = new DB_StatementBuilder( $prefix );
$assertion = $prefix;
$creation = $builder->getPrefix();
$this->assertEquals( $assertion, $creation );
@@ -465,7 +465,7 @@
}
}

-class Test_Database_StatementBuilderInstance extends
Database_StatementBuilder
+class Test_DB_StatementBuilderInstance extends DB_StatementBuilder
{
public function getProtectedVar( $varName )
{
=======================================
--- /branches/0.8.1/Test/Database/StatementCollectionTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/DB/StatementCollectionTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_StatementCollection.
+ * TestUnit of DB_StatementCollection.
* @package Tests.{classPackage}
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
@@ -8,16 +8,16 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_StatementCollection.
+ * TestUnit of DB_StatementCollection.
* @package Tests.{classPackage}
* @extends Test_Case
- * @uses Database_StatementCollection
- * @uses Database_StatementBuilder
+ * @uses DB_StatementCollection
+ * @uses DB_StatementBuilder
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
* @version 0.1
*/
-class Test_Database_StatementCollectionTest extends Test_Case
+class Test_DB_StatementCollectionTest extends Test_Case
{
/**
* Setup for every Test.
@@ -26,8 +26,8 @@
*/
public function setUp()
{
- $this->builder = new
Test_Database_StatementBuilderInStatementCollectionInstance( "prefix_" );
- $this->collection = new Test_Database_StatementCollectionInstance(
$this->builder );
+ $this->builder = new
Test_DB_StatementBuilderInStatementCollectionInstance( "prefix_" );
+ $this->collection = new Test_DB_StatementCollectionInstance(
$this->builder );
}

/**
@@ -46,7 +46,7 @@
*/
public function testConstruct()
{
- $collection = new Test_Database_StatementCollectionInstance(
$this->builder );
+ $collection = new Test_DB_StatementCollectionInstance( $this->builder );
$assertion = $this->builder;
$creation = $this->collection->getProtectedVar( 'builder' );
$this->assertEquals( $assertion, $creation );
@@ -141,7 +141,7 @@
}
}

-class Test_Database_StatementCollectionInstance extends
Database_StatementCollection
+class Test_DB_StatementCollectionInstance extends DB_StatementCollection
{
public function getProtectedVar( $varName )
{
@@ -151,7 +151,7 @@
}
}

-class Test_Database_StatementBuilderInStatementCollectionInstance extends
Database_StatementBuilder
+class Test_DB_StatementBuilderInStatementCollectionInstance extends
DB_StatementBuilder
{
public function getProtectedVar( $varName )
{
=======================================
--- /branches/0.8.1/Test/Database/TableReaderTest.php Sat May 23 06:59:40
2015 UTC
+++ /branches/0.8.1/Test/DB/TableReaderTest.php Thu May 28 07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_TableReader.
+ * TestUnit of DB_TableReader.
* @package Tests.database
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
@@ -8,16 +8,16 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_TableReader.
+ * TestUnit of DB_TableReader.
* @package Tests.database
* @extends Test_Case
- * @uses Database_MySQL_Connection
- * @uses Database_TableReader
+ * @uses DB_MySQL_Connection
+ * @uses DB_TableReader
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
* @version 0.1
*/
-class Test_Database_TableReaderTest extends Test_Case
+class Test_DB_TableReaderTest extends Test_Case
{
/**
* Constructor.
@@ -58,7 +58,7 @@
if( !extension_loaded( 'mysql' ) )
$this->markTestSkipped( "Support for MySQL is missing" );

- $this->connection = new Database_MySQL_Connection( $this->logFile );
+ $this->connection = new DB_MySQL_Connection( $this->logFile );
$this->connection->connect( $this->host, $this->username,
$this->password, $this->database );

$this->mysql = mysql_connect( $this->host, $this->username,
$this->password ) or die( mysql_error() );
@@ -68,7 +68,7 @@
if( trim( $part ) )
mysql_query( $part ) or die( mysql_error() );

- $this->reader = new Database_TableReader( $this->connection,
$this->tableName, $this->columns, $this->primaryKey );
+ $this->reader = new DB_TableReader( $this->connection, $this->tableName,
$this->columns, $this->primaryKey );
$this->reader->setForeignKeys( $this->indices );
}

@@ -91,7 +91,7 @@
*/
public function testConstruct1()
{
- $reader = new Database_TableReader( $this->connection, "table",
array( 'col1', 'col2' ), 'col2', 1 );
+ $reader = new DB_TableReader( $this->connection, "table",
array( 'col1', 'col2' ), 'col2', 1 );

$assertion = 'table';
$creation = $reader->getTableName();
@@ -117,7 +117,7 @@
*/
public function testConstruct2()
{
- $reader = new Database_TableReader( $this->connection,
$this->tableName, $this->columns, $this->primaryKey, 1 );
+ $reader = new DB_TableReader( $this->connection, $this->tableName,
$this->columns, $this->primaryKey, 1 );

$assertion = array( 'id' => 1 );
$creation = array_slice( $reader->getData( TRUE ), 0, 1 );
=======================================
--- /branches/0.8.1/Test/Database/TableWriterTest.php Sat May 23 06:59:40
2015 UTC
+++ /branches/0.8.1/Test/DB/TableWriterTest.php Thu May 28 07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of Database_TableWriter.
+ * TestUnit of DB_TableWriter.
* @package Tests.database
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
@@ -8,16 +8,16 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of Database_TableWriter.
+ * TestUnit of DB_TableWriter.
* @package Tests.database
* @extends Test_Case
- * @uses Database_MySQL_Connection
- * @uses Database_TableWriter
+ * @uses DB_MySQL_Connection
+ * @uses DB_TableWriter
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
* @version 0.1
*/
-class Test_Database_TableWriterTest extends Test_Case
+class Test_DB_TableWriterTest extends Test_Case
{
/**
* Constructor.
@@ -33,7 +33,7 @@
$this->database = self::$config['unitTest-Database']['database'];
$this->path = dirname( __FILE__ )."/";
$this->logFile = $this->path."errors.log";
- $options = array();
+ $this->options = array();

$this->tableName = "transactions";
$this->columns = array(
@@ -59,8 +59,8 @@
if( !extension_loaded( 'mysql' ) )
$this->markTestSkipped( 'Missing MySQL support' );

- $this->connection = new Database_MySQL_Connection( $this->logFile );
- $this->connection->connect( $this->host, $this->username,
$this->password );
+ $this->connection = new DB_MySQL_Connection( $this->logFile );
+ $this->connection->connect( $this->host, $this->username,
$this->password, $this->options );

$this->mysql = mysql_connect( $this->host, $this->username,
$this->password ) or die( mysql_error() );
mysql_select_db( $this->database );
@@ -69,7 +69,7 @@
if( trim( $part ) )
mysql_query( $part ) or die( mysql_error() );

- $this->writer = new Database_TableWriter( $this->connection,
$this->tableName, $this->columns, $this->primaryKey );
+ $this->writer = new DB_TableWriter( $this->connection, $this->tableName,
$this->columns, $this->primaryKey );
$this->writer->setForeignKeys( $this->indices );
}

=======================================
--- /branches/0.8.1/Test/File/Arc/BzipTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/FS/File/Arc/BzipTest.php Thu May 28 07:36:27 2015
UTC
@@ -10,11 +10,11 @@
* TestUnit of Bzip File.
* @package Tests.file.arc
* @extends Test_Case
- * @uses File_Arc_Bzip
+ * @uses FS_File_Arc_Bzip
* @author Christian Würker <christia...@ceusmedia.de>
* @version 0.1
*/
-class Test_File_Arc_BzipTest extends Test_Case
+class Test_FS_File_Arc_BzipTest extends Test_Case
{
/** @var string $fileName URL of Archive File Name */
private $fileName;
@@ -38,7 +38,7 @@

public function testWriteString()
{
- $arc = new File_Arc_Bzip( $this->fileName );
+ $arc = new FS_File_Arc_Bzip( $this->fileName );
$arc->writeString( "test" );

$assertion = TRUE;
@@ -52,7 +52,7 @@

public function testReadString()
{
- $arc = new File_Arc_Bzip( $this->fileName );
+ $arc = new FS_File_Arc_Bzip( $this->fileName );
$arc->writeString( "test" );

$assertion = "test";
=======================================
--- /branches/0.8.1/Test/File/Arc/GzipTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/FS/File/Arc/GzipTest.php Thu May 28 07:36:27 2015
UTC
@@ -10,11 +10,11 @@
* TestUnit of Gzip File.
* @package Tests.file.arc
* @extends Test_Case
- * @uses File_Arc_Gzip
+ * @uses FS_File_Arc_Gzip
* @author Christian Würker <christia...@ceusmedia.de>
* @version 0.1
*/
-class Test_File_Arc_GzipTest extends Test_Case
+class Test_FS_File_Arc_GzipTest extends Test_Case
{
/** @var string $fileName URL of Archive File Name */
private $fileName;
@@ -38,7 +38,7 @@

public function testWriteString()
{
- $arc = new File_Arc_Gzip( $this->fileName );
+ $arc = new FS_File_Arc_Gzip( $this->fileName );
$arc->writeString( "test" );

$assertion = TRUE;
@@ -52,7 +52,7 @@

public function testReadString()
{
- $arc = new File_Arc_Gzip( $this->fileName );
+ $arc = new FS_File_Arc_Gzip( $this->fileName );
$arc->writeString( "test" );

$assertion = "test";
=======================================
--- /branches/0.8.1/Test/File/Arc/TarTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/FS/File/Arc/TarTest.php Thu May 28 07:36:27 2015
UTC
@@ -10,11 +10,11 @@
* TestUnit of Tar File.
* @package Tests.file.arc
* @extends Test_Case
- * @uses File_Arc_Tar
+ * @uses FS_File_Arc_Tar
* @author Christian Würker <christia...@ceusmedia.de>
* @version 0.1
*/
-class Test_File_Arc_TarTest extends Test_Case
+class Test_FS_File_Arc_TarTest extends Test_Case
{
/** @var string $fileName URL of Archive File Name */
private $fileName;
@@ -36,7 +36,7 @@

public function testAddFile()
{
- $arc = new File_Arc_Tar();
+ $arc = new FS_File_Arc_Tar();
$arc->addFile( $this->path."TarTest.php" );

$this->assertTrue( $arc->save( $this->fileName ) > 0 );
=======================================
--- /branches/0.8.1/Test/File/CacheTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/FS/File/CacheTest.php Thu May 28 07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_Cache.
+ * TestUnit of FS_File_Cache.
* @package Tests.file
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.04.2009
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_Cache.
+ * TestUnit of FS_File_Cache.
* @package Tests.file
* @extends Test_Case
- * @uses File_Cache
+ * @uses FS_File_Cache
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.04.2009
* @version 0.1
*/
-final class Test_File_CacheTest extends Test_Case
+final class Test_FS_File_CacheTest extends Test_Case
{
/**
* Constructor.
@@ -25,11 +25,11 @@
*/
public function __construct()
{
- Test_MockAntiProtection::createMockClass( 'File_Cache' );
+ Test_MockAntiProtection::createMockClass( 'FS_File_Cache' );
$this->path = dirname( __FILE__ )."/";
$this->pathCache = $this->path."__cacheTestPath/";
}
-
+
/**
* Setup for every Test.
* @access public
@@ -40,7 +40,7 @@
if( !file_exists( $this->pathCache ) )
@mkdir( $this->pathCache );
}
-
+
/**
* Cleanup after every Test.
* @access public
@@ -67,7 +67,7 @@
*/
public function test__construct1()
{
- $mock = new Test_File_Cache_MockAntiProtection( $this->pathCache );
+ $mock = new Test_FS_File_Cache_MockAntiProtection( $this->pathCache );
$assertion = $this->pathCache;
$creation = $mock->getProtectedVar( 'path' );
$this->assertEquals( $assertion, $creation );
@@ -80,8 +80,8 @@
*/
public function test__construct2()
{
- $path = substr( $this->pathCache, 0, -1 );
- $mock = new Test_File_Cache_MockAntiProtection( $path );
+ $path = substr( $this->pathCache, 0, -1 );
+ $mock = new Test_FS_File_Cache_MockAntiProtection( $path );
$assertion = $this->pathCache;
$creation = $mock->getProtectedVar( 'path' );
$this->assertEquals( $assertion, $creation );
@@ -95,7 +95,7 @@
public function test__constructException()
{
$this->setExpectedException( 'RuntimeException' );
- new File_Cache( "not_existing" );
+ new FS_File_Cache( "not_existing" );
}

/**
@@ -105,7 +105,7 @@
*/
public function testCleanUp()
{
- $cache = new File_Cache( $this->pathCache, 1 );
+ $cache = new FS_File_Cache( $this->pathCache, 1 );
$fileName = $this->pathCache."test.serial";
file_put_contents( $fileName, "test" );
touch( $fileName, time() - 10 );
@@ -126,7 +126,7 @@
*/
public function testCleanUpException1()
{
- $cache = new File_Cache( $this->pathCache );
+ $cache = new FS_File_Cache( $this->pathCache );
$this->setExpectedException( 'InvalidArgumentException' );
$cache->cleanUp();
}
@@ -138,7 +138,7 @@
*/
public function testCleanUpException2()
{
- $cache = new File_Cache( $this->pathCache, 0 );
+ $cache = new FS_File_Cache( $this->pathCache, 0 );
$this->setExpectedException( 'InvalidArgumentException' );
$cache->cleanUp();
}
@@ -150,7 +150,7 @@
*/
public function testCount()
{
- $cache = new File_Cache( $this->pathCache, 1 );
+ $cache = new FS_File_Cache( $this->pathCache, 1 );
$cache->set( 'test1', 'value1' );
$cache->set( 'test2', 'value2' );
$cache->set( 'test3', 'value3' );
@@ -168,7 +168,7 @@
*/
public function testFlush()
{
- $cache = new File_Cache( $this->pathCache, 1 );
+ $cache = new FS_File_Cache( $this->pathCache, 1 );
$cache->set( 'test1', 'value1' );
$cache->set( 'test2', 'value2' );
$cache->set( 'test3', 'value3' );
@@ -199,7 +199,7 @@
*/
public function testGet1()
{
- $cache = new File_Cache( $this->pathCache, 1 );
+ $cache = new FS_File_Cache( $this->pathCache, 1 );
$assertion = NULL;
$creation = $cache->get( 'testKey' );
$this->assertEquals( $assertion, $creation );
@@ -212,7 +212,7 @@
*/
public function testGet2()
{
- $cache = new File_Cache( $this->pathCache, 1 );
+ $cache = new FS_File_Cache( $this->pathCache, 1 );
$cache->set( 'testKey', "testValue" );

$assertion = "testValue";
@@ -233,10 +233,10 @@
*/
public function testGet3()
{
- $cache = new File_Cache( $this->pathCache, 10 );
+ $cache = new FS_File_Cache( $this->pathCache, 10 );
$cache->set( 'testKey', "testValue" );

- $cache = new File_Cache( $this->pathCache, 10 );
+ $cache = new FS_File_Cache( $this->pathCache, 10 );
$assertion = "testValue";
$creation = $cache->get( 'testKey' );
$this->assertEquals( $assertion, $creation );
@@ -250,7 +250,7 @@
*/
public function testGet4()
{
- $cache = new File_Cache( $this->pathCache, 1 );
+ $cache = new FS_File_Cache( $this->pathCache, 1 );
$cache->set( 'testKey', "testValue" );

sleep( 1 );
@@ -266,7 +266,7 @@
*/
public function testGet5()
{
- $mock = new Test_File_Cache_MockAntiProtection( $this->pathCache );
+ $mock = new Test_FS_File_Cache_MockAntiProtection( $this->pathCache );
$mock->setProtectedVar( 'data', array( 'testKey' => 'testValue' ) );

$assertion = NULL;
@@ -281,7 +281,7 @@
*/
public function testHas1()
{
- $cache = new File_Cache( $this->pathCache, 1 );
+ $cache = new FS_File_Cache( $this->pathCache, 1 );
$assertion = FALSE;
$creation = $cache->has( 'testKey' );
$this->assertEquals( $assertion, $creation );
@@ -294,7 +294,7 @@
*/
public function testHas2()
{
- $cache = new File_Cache( $this->pathCache, 10 );
+ $cache = new FS_File_Cache( $this->pathCache, 10 );
$cache->set( 'testKey', "testValue" );

$assertion = TRUE;
@@ -315,10 +315,10 @@
*/
public function testHas3()
{
- $cache = new File_Cache( $this->pathCache, 10 );
+ $cache = new FS_File_Cache( $this->pathCache, 10 );
$cache->set( 'testKey', "testValue" );

- $cache = new File_Cache( $this->pathCache, 10 );
+ $cache = new FS_File_Cache( $this->pathCache, 10 );
$assertion = TRUE;
$creation = $cache->has( 'testKey' );
$this->assertEquals( $assertion, $creation );
@@ -331,7 +331,7 @@
*/
public function testHas4()
{
- $cache = new File_Cache( $this->pathCache, 1 );
+ $cache = new FS_File_Cache( $this->pathCache, 1 );
$cache->set( 'testKey', "testValue" );

sleep( 1 );
@@ -347,7 +347,7 @@
*/
public function testHas5()
{
- $mock = new Test_File_Cache_MockAntiProtection( $this->pathCache );
+ $mock = new Test_FS_File_Cache_MockAntiProtection( $this->pathCache );
$mock->setProtectedVar( 'data', array( 'testKey' => 'testValue' ) );

$assertion = FALSE;
@@ -362,7 +362,7 @@
*/
public function testRemove()
{
- $cache = new File_Cache( $this->pathCache, 1 );
+ $cache = new FS_File_Cache( $this->pathCache, 1 );
$cache->set( 'testKey', "testValue" );

$assertion = TRUE;
@@ -381,7 +381,7 @@
*/
public function testSet()
{
- $mock = new Test_File_Cache_MockAntiProtection( $this->pathCache );
+ $mock = new Test_FS_File_Cache_MockAntiProtection( $this->pathCache );
$mock->set( 'testKey', "testValue" );

$assertion = array( 'testKey' => "testValue" );
=======================================
--- /branches/0.8.1/Test/File/Configuration/ConverterTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/FS/File/Configuration/ConverterTest.php Thu May 28
07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_Configuration_Converter.
+ * TestUnit of FS_File_Configuration_Converter.
* @package Tests.file.configuration
* @author Christian Würker <christia...@ceusmedia.de>
* @since 08.05.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_Configuration_Converter.
+ * TestUnit of FS_File_Configuration_Converter.
* @package Tests.file.configuration
* @extends Test_Case
- * @uses File_Configuration_Converter
+ * @uses FS_File_Configuration_Converter
* @author Christian Würker <christia...@ceusmedia.de>
* @since 08.05.2008
* @version 0.1
*/
-class Test_File_Configuration_ConverterTest extends Test_Case
+class Test_FS_File_Configuration_ConverterTest extends Test_Case
{
/**
* Constructor.
@@ -63,7 +63,7 @@
$targetFile = $this->path."test.ini.json";
$assertFile = $this->path."test.json";

- $length = File_Configuration_Converter::convertIniToJson( $sourceFile,
$targetFile );
+ $length = FS_File_Configuration_Converter::convertIniToJson(
$sourceFile, $targetFile );

$assertion = TRUE;
$creation = is_int( $length );
@@ -89,7 +89,7 @@
$targetFile = $this->path."test.ini.xml";
$assertFile = $this->path."test.xml";

- $length = File_Configuration_Converter::convertIniToXml( $sourceFile,
$targetFile );
+ $length = FS_File_Configuration_Converter::convertIniToXml(
$sourceFile, $targetFile );

$assertion = TRUE;
$creation = is_int( $length );
@@ -115,7 +115,7 @@
$targetFile = $this->path."test.json.ini";
$assertFile = $this->path."test.ini";

- $length = File_Configuration_Converter::convertJsonToIni( $sourceFile,
$targetFile );
+ $length = FS_File_Configuration_Converter::convertJsonToIni(
$sourceFile, $targetFile );

$assertion = TRUE;
$creation = is_int( $length );
@@ -141,7 +141,7 @@
$targetFile = $this->path."test.json.xml";
$assertFile = $this->path."test.xml";

- $length = File_Configuration_Converter::convertJsonToXml( $sourceFile,
$targetFile );
+ $length = FS_File_Configuration_Converter::convertJsonToXml(
$sourceFile, $targetFile );

$assertion = TRUE;
$creation = is_int( $length );
@@ -167,7 +167,7 @@
$targetFile = $this->path."test.xml.ini";
$assertFile = $this->path."test.ini";

- $length = File_Configuration_Converter::convertXmlToIni( $sourceFile,
$targetFile );
+ $length = FS_File_Configuration_Converter::convertXmlToIni(
$sourceFile, $targetFile );

$assertion = TRUE;
$creation = is_int( $length );
@@ -193,7 +193,7 @@
$targetFile = $this->path."test.xml.json";
$assertFile = $this->path."test.json";

- $length = File_Configuration_Converter::convertXmlToJson( $sourceFile,
$targetFile );
+ $length = FS_File_Configuration_Converter::convertXmlToJson(
$sourceFile, $targetFile );

$assertion = TRUE;
$creation = is_int( $length );
=======================================
--- /branches/0.8.1/Test/File/Configuration/ReaderTest.php Sat May 23
06:59:40 2015 UTC
+++ /branches/0.8.1/Test/FS/File/Configuration/ReaderTest.php Thu May 28
07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_Configuration_Reader.
+ * TestUnit of FS_File_Configuration_Reader.
* @package Tests.
* @author Christian Würker <christia...@ceusmedia.de>
* @since 08.05.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_Configuration_Reader.
+ * TestUnit of FS_File_Configuration_Reader.
* @package Tests.
* @extends Test_Case
- * @uses File_Configuration_Reader
+ * @uses FS_File_Configuration_Reader
* @author Christian Würker <christia...@ceusmedia.de>
* @since 08.05.2008
* @version 0.1
*/
-class Test_File_Configuration_ReaderTest extends Test_Case
+class Test_FS_File_Configuration_ReaderTest extends Test_Case
{
/**
* Constructor.
@@ -58,7 +58,7 @@
*/
public function testConstructIni()
{
- $reader = new File_Configuration_Reader( $this->path."test.ini" );
+ $reader = new FS_File_Configuration_Reader( $this->path."test.ini" );
$assertion = $this->data;
$creation = $reader->getAll();
$this->assertEquals( $assertion, $creation );
@@ -71,7 +71,7 @@
*/
public function testConstructIniCache()
{
- $reader = new File_Configuration_Reader( $this->path."test.ini",
$this->path );
+ $reader = new FS_File_Configuration_Reader( $this->path."test.ini",
$this->path );
$assertion = $this->data;
$creation = $reader->getAll();
$this->assertEquals( $assertion, $creation );
@@ -84,8 +84,8 @@
*/
public function testConstructIniQuick()
{
- File_Configuration_Reader::$iniQuickLoad = TRUE;
- $reader = new File_Configuration_Reader( $this->path."test.ini" );
+ FS_File_Configuration_Reader::$iniQuickLoad = TRUE;
+ $reader = new FS_File_Configuration_Reader( $this->path."test.ini" );
$stringData = array();
foreach( $this->data as $key => $value )
$stringData[$key] = (string) $value;
@@ -101,7 +101,7 @@
*/
public function testConstructJson()
{
- $reader = new File_Configuration_Reader( $this->path."test.json" );
+ $reader = new FS_File_Configuration_Reader( $this->path."test.json" );
$assertion = $this->data;
$creation = $reader->getAll();
$this->assertEquals( $assertion, $creation );
@@ -114,7 +114,7 @@
*/
public function testConstructJsonCache()
{
- $reader = new File_Configuration_Reader( $this->path."test.json",
$this->path );
+ $reader = new FS_File_Configuration_Reader( $this->path."test.json",
$this->path );
$assertion = $this->data;
$creation = $reader->getAll();
$this->assertEquals( $assertion, $creation );
@@ -127,7 +127,7 @@
*/
public function testConstructYaml()
{
- $reader = new File_Configuration_Reader( $this->path."test.yaml" );
+ $reader = new FS_File_Configuration_Reader( $this->path."test.yaml" );
$assertion = $this->data;
$creation = $reader->getAll();
$this->assertEquals( $assertion, $creation );
@@ -140,7 +140,7 @@
*/
public function testConstructYamlCache()
{
- $reader = new File_Configuration_Reader( $this->path."test.yaml",
$this->path );
+ $reader = new FS_File_Configuration_Reader( $this->path."test.yaml",
$this->path );
$assertion = $this->data;
$creation = $reader->getAll();
$this->assertEquals( $assertion, $creation );
@@ -153,7 +153,7 @@
*/
public function testConstructXml()
{
- $reader = new File_Configuration_Reader( $this->path."test.xml" );
+ $reader = new FS_File_Configuration_Reader( $this->path."test.xml" );
$assertion = $this->data;
$creation = $reader->getAll();
$this->assertEquals( $assertion, $creation );
@@ -166,7 +166,7 @@
*/
public function testConstructXmlCache()
{
- $reader = new File_Configuration_Reader( $this->path."test.xml",
$this->path );
+ $reader = new FS_File_Configuration_Reader( $this->path."test.xml",
$this->path );
$assertion = $this->data;
$creation = $reader->getAll();
$this->assertEquals( $assertion, $creation );
@@ -180,7 +180,7 @@
public function testConstructExceptionNotExisting()
{
$this->setExpectedException( 'RuntimeException' );
- new File_Configuration_Reader( $this->path."name.not_supported" );
+ new FS_File_Configuration_Reader( $this->path."name.not_supported" );
}

/**
@@ -193,7 +193,7 @@
$fileName = $this->path."filename.xyz";
file_put_contents( $fileName, "" );
$this->setExpectedException( 'InvalidArgumentException' );
- new File_Configuration_Reader( $fileName );
+ new FS_File_Configuration_Reader( $fileName );
unlink( $fileName );
}
}
=======================================
--- /branches/0.8.1/Test/File/BackupTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/FS/File/BackupTest.php Thu May 28 07:36:27 2015 UTC
@@ -1,20 +1,20 @@
<?php
/**
* Test class for File_Backup.
* @package Tests.file
* @author Christian Würker <christia...@ceusmedia.de>
* @version 0.1
*/
require_once 'Test/initLoaders.php';
/**
* Test class for File_Backup.
* @package Tests.file
* @extends Test_Case
- * @uses File_Editor
+ * @uses FS_File_Editor
* @author Christian Würker <christia...@ceusmedia.de>
* @version 0.1
*/
-class Test_File_BackupTest extends Test_Case{
+class Test_FS_File_BackupTest extends Test_Case{

protected $filePath;
protected $path;
@@ -28,7 +28,7 @@
if( !file_exists( $this->path ) )
mkdir( $this->path );
file_put_contents( $this->filePath, $this->time );
- $this->file = new File_Backup( $this->filePath );
+ $this->file = new FS_File_Backup( $this->filePath );
}

public function tearDown(){
=======================================
--- /branches/0.8.1/Test/File/Block/ReaderTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/FS/File/Block/ReaderTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_Block_Reader.
+ * TestUnit of FS_File_Block_Reader.
* @package Tests.file
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_Block_Reader.
+ * TestUnit of FS_File_Block_Reader.
* @package Tests.file
* @extends Test_Case
- * @uses File_Block_Reader
+ * @uses FS_File_Block_Reader
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.06.2008
* @version 0.1
*/
-class Test_File_Block_ReaderTest extends Test_Case
+class Test_FS_File_Block_ReaderTest extends Test_Case
{
/**
* Constructor.
@@ -54,7 +54,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_Block_Reader::__construct();
+ $creation = FS_File_Block_Reader::__construct();
$this->assertEquals( $assertion, $creation );
}

@@ -67,7 +67,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_Block_Reader::getBlockNames();
+ $creation = FS_File_Block_Reader::getBlockNames();
$this->assertEquals( $assertion, $creation );
}

@@ -80,7 +80,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_Block_Reader::getBlock();
+ $creation = FS_File_Block_Reader::getBlock();
$this->assertEquals( $assertion, $creation );
}

@@ -93,7 +93,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_Block_Reader::hasBlock();
+ $creation = FS_File_Block_Reader::hasBlock();
$this->assertEquals( $assertion, $creation );
}

@@ -106,7 +106,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_Block_Reader::getBlocks();
+ $creation = FS_File_Block_Reader::getBlocks();
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/File/Block/WriterTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/FS/File/Block/WriterTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_Block_Writer.
+ * TestUnit of FS_File_Block_Writer.
* @package Tests.file.block
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_Block_Writer.
+ * TestUnit of FS_File_Block_Writer.
* @package Tests.file.block
* @extends Test_Case
- * @uses File_Block_Writer
+ * @uses FS_File_Block_Writer
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.06.2008
* @version 0.1
*/
-class Test_File_Block_WriterTest extends Test_Case
+class Test_FS_File_Block_WriterTest extends Test_Case
{
/**
* Constructor.
@@ -54,7 +54,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_Block_Writer::__construct();
+ $creation = FS_File_Block_Writer::__construct();
$this->assertEquals( $assertion, $creation );
}

@@ -67,7 +67,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_Block_Writer::writeBlocks();
+ $creation = FS_File_Block_Writer::writeBlocks();
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/File/CSV/IteratorTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/FS/File/CSV/IteratorTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_CSV_Iterator.
+ * TestUnit of FS_File_CSV_Iterator.
* @package Tests.File.CSV
* @author Christian Würker <christia...@ceusmedia.de>
* @since 09.08.2010
@@ -8,15 +8,15 @@
*/
require_once( 'Test/initLoaders.php' );
/**
- * TestUnit of File_CSV_Iterator.
+ * TestUnit of FS_File_CSV_Iterator.
* @package Tests.File.CSV
* @extends Test_Case
- * @uses File_CSV_Iterator
+ * @uses FS_File_CSV_Iterator
* @author Christian Würker <christia...@ceusmedia.de>
* @since 09.08.2010
* @version 0.1
*/
-class Test_File_CSV_IteratorTest extends Test_Case
+class Test_FS_File_CSV_IteratorTest extends Test_Case
{
/**
* Constructor.
@@ -53,7 +53,7 @@
*/
public function test__construct()
{
- $mock = Test_MockAntiProtection::getInstance( 'File_CSV_Iterator',
$this->path.'read.csv', '|', '#' );
+ $mock = Test_MockAntiProtection::getInstance( 'FS_File_CSV_Iterator',
$this->path.'read.csv', '|', '#' );

$assertion = TRUE;
$creation = is_object( $mock );
@@ -80,7 +80,7 @@
public function test__constructException()
{
$this->setExpectedException( 'RuntimeException' );
- new File_CSV_Iterator( 'not_existing' );
+ new FS_File_CSV_Iterator( 'not_existing' );
}

/**
@@ -90,7 +90,7 @@
*/
public function testRewind()
{
- $iterator = new File_CSV_Iterator( $this->path.'read.csv', ';' );
+ $iterator = new FS_File_CSV_Iterator( $this->path.'read.csv', ';' );
$iterator->next();

$assertion = 1;
@@ -123,7 +123,7 @@
*/
public function testCurrent()
{
- $iterator = new File_CSV_Iterator( $this->path.'read.csv', ';' );
+ $iterator = new FS_File_CSV_Iterator( $this->path.'read.csv', ';' );
$iterator->valid();

$assertion = array( 'id', 'col1', 'col2' );
@@ -143,7 +143,7 @@
*/
public function testKey()
{
- $iterator = new File_CSV_Iterator( $this->path.'read.csv', ';' );
+ $iterator = new FS_File_CSV_Iterator( $this->path.'read.csv', ';' );

$assertion = 0;
$creation = $iterator->key();
@@ -162,7 +162,7 @@
*/
public function testNext1()
{
- $iterator = new File_CSV_Iterator( $this->path.'read.csv', ';' );
+ $iterator = new FS_File_CSV_Iterator( $this->path.'read.csv', ';' );

$assertion = TRUE;
$creation = $iterator->next();
@@ -183,7 +183,7 @@
*/
public function testNext2()
{
- $iterator = new File_CSV_Iterator( $this->path.'empty.csv', ';' );
+ $iterator = new FS_File_CSV_Iterator( $this->path.'empty.csv', ';' );

$assertion = FALSE;
$creation = $iterator->next();
@@ -197,7 +197,7 @@
*/
public function testValid1()
{
- $iterator = new File_CSV_Iterator( $this->path.'read.csv', ';' );
+ $iterator = new FS_File_CSV_Iterator( $this->path.'read.csv', ';' );
$assertion = TRUE;
$creation = $iterator->valid();
$this->assertEquals( $assertion, $creation );
@@ -216,7 +216,7 @@
*/
public function testValid2()
{
- $iterator = new File_CSV_Iterator( $this->path.'empty.csv', ';' );
+ $iterator = new FS_File_CSV_Iterator( $this->path.'empty.csv', ';' );
$assertion = FALSE;
$creation = $iterator->valid();
$this->assertEquals( $assertion, $creation );
=======================================
--- /branches/0.8.1/Test/File/CSV/ReaderTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/FS/File/CSV/ReaderTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_CSV_Reader.
+ * TestUnit of FS_File_CSV_Reader.
* @package Tests.File.CSV
* @author Christian Würker <christia...@ceusmedia.de>
* @since 09.08.2010
@@ -8,15 +8,15 @@
*/
require_once( 'Test/initLoaders.php' );
/**
- * TestUnit of File_CSV_Reader.
+ * TestUnit of FS_File_CSV_Reader.
* @package Tests.File.CSV
* @extends Test_Case
- * @uses File_CSV_Reader
+ * @uses FS_File_CSV_Reader
* @author Christian Würker <christia...@ceusmedia.de>
* @since 09.08.2010
* @version 0.1
*/
-class Test_File_CSV_ReaderTest extends Test_Case
+class Test_FS_File_CSV_ReaderTest extends Test_Case
{
/**
* Constructor.
@@ -28,7 +28,7 @@
$this->pathName = dirname( __FILE__ ).'/';
$this->fileName = $this->pathName.'read.csv';
}
-
+
/**
* Setup for every Test.
* @access public
@@ -36,9 +36,9 @@
*/
public function setUp()
{
- $this->reader = new File_CSV_Reader( $this->fileName, TRUE );
+ $this->reader = new FS_File_CSV_Reader( $this->fileName, TRUE );
}
-
+
/**
* Cleanup after every Test.
* @access public
@@ -55,7 +55,7 @@
*/
public function test__construct()
{
- $mock = Test_MockAntiProtection::getInstance( 'File_CSV_Reader',
$this->fileName, TRUE, '|', '#' );
+ $mock = Test_MockAntiProtection::getInstance( 'FS_File_CSV_Reader',
$this->fileName, TRUE, '|', '#' );

$assertion = TRUE;
$creation = is_object( $mock );
@@ -85,7 +85,7 @@
*/
public function testGetColumnHeaders()
{
- $reader = new File_CSV_Reader( $this->fileName, TRUE );
+ $reader = new FS_File_CSV_Reader( $this->fileName, TRUE );
$assertion = array( 'id', 'col1', 'col2' );
$creation = $this->reader->getColumnHeaders();
$this->assertEquals( $assertion, $creation );
@@ -98,7 +98,7 @@
*/
public function testGetColumnHeadersException1()
{
- $reader = new File_CSV_Reader( $this->fileName, FALSE );
+ $reader = new FS_File_CSV_Reader( $this->fileName, FALSE );
$this->setExpectedException( 'RuntimeException' );
$reader->getColumnHeaders();
}
@@ -110,7 +110,7 @@
*/
public function testGetColumnHeadersException2()
{
- $reader = new File_CSV_Reader( $this->pathName.'empty.csv', TRUE );
+ $reader = new FS_File_CSV_Reader( $this->pathName.'empty.csv', TRUE );
$this->setExpectedException( 'RuntimeException' );
$reader->getColumnHeaders();
}
@@ -138,7 +138,7 @@
$creation = $this->reader->getDelimiter();
$this->assertEquals( $assertion, $creation );

- $reader = new File_CSV_Reader( $this->fileName, TRUE, '_' );
+ $reader = new FS_File_CSV_Reader( $this->fileName, TRUE, '_' );
$assertion = '_';
$creation = $reader->getDelimiter();
$this->assertEquals( $assertion, $creation );
@@ -155,7 +155,7 @@
$creation = $this->reader->getEnclosure();
$this->assertEquals( $assertion, $creation );

- $reader = new File_CSV_Reader( $this->fileName, TRUE, ';', '_' );
+ $reader = new FS_File_CSV_Reader( $this->fileName, TRUE, ';', '_' );
$assertion = '_';
$creation = $reader->getEnclosure();
$this->assertEquals( $assertion, $creation );
@@ -1,20 +1,20 @@
<?php
/**
- * Test class for File_Backup.
+ * Test class for FS_File_Backup.
* @package Tests.file
* @author Christian Würker <christia...@ceusmedia.de>
@@ -1,20 +1,20 @@
require_once 'Test/initLoaders.php';
/**
- * Test class for File_Backup.
+ * Test class for FS_File_Backup.
* @package Tests.file
* @extends Test_Case
=======================================
--- /branches/0.8.1/Test/File/EditorTest.php Sat May 23 06:59:40 2015 UTC
+++ /branches/0.8.1/Test/FS/File/EditorTest.php Thu May 28 07:36:27 2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_Editor.
+ * TestUnit of FS_File_Editor.
* @package Tests.file
* @author Christian Würker <christia...@ceusmedia.de>
* @since 04.07.2008
@@ -8,17 +8,17 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_Editor.
+ * TestUnit of FS_File_Editor.
* @package Tests.file
* @extends Test_Case
- * @uses File_Editor
+ * @uses FS_File_Editor
* @author Christian Würker <christia...@ceusmedia.de>
* @since 04.07.2008
* @version 0.1
*/
-class Test_File_EditorTest extends Test_Case
+class Test_FS_File_EditorTest extends Test_Case
{
/** @var File_Editor $editor Instance of File Editor */
private $editor = NULL;
/** @var string $fileName File Name of Test File */
private $fileName = "editor.test";
@@ -36,7 +36,7 @@
{
$this->path = dirname( __FILE__ )."/";
$this->fileName = $this->path.$this->fileName;
- $this->editor = new File_Editor( $this->fileName );
+ $this->editor = new FS_File_Editor( $this->fileName );
}

/**
@@ -72,7 +72,7 @@
$this->assertEquals( $assertion, $creation );

$assertion = TRUE;
- $creation = File_Editor::delete( $this->fileName );
+ $creation = FS_File_Editor::delete( $this->fileName );
$this->assertEquals( $assertion, $creation );

$assertion = FALSE;
=======================================
--- /branches/0.8.1/Test/File/ICal/BuilderTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/FS/File/ICal/BuilderTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_ICal_Builder.
+ * TestUnit of FS_File_ICal_Builder.
* @package Tests.file_ical
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_ICal_Builder.
+ * TestUnit of FS_File_ICal_Builder.
* @package Tests.file_ical
* @extends Test_Case
- * @uses File_ICal_Builder
+ * @uses FS_File_ICal_Builder
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.06.2008
* @version 0.1
*/
-class Test_File_ICal_BuilderTest extends Test_Case
+class Test_FS_File_ICal_BuilderTest extends Test_Case
{
/**
* Constructor.
@@ -54,7 +54,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_ICal_Builder::__construct();
+ $creation = FS_File_ICal_Builder::__construct();
$this->assertEquals( $assertion, $creation );
}

@@ -67,7 +67,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_ICal_Builder::build();
+ $creation = FS_File_ICal_Builder::build();
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/File/ICal/ParserTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/FS/File/ICal/ParserTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_ICal_Parser.
+ * TestUnit of FS_File_ICal_Parser.
* @package Tests.file_ical.file
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.06.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_ICal_Parser.
+ * TestUnit of FS_File_ICal_Parser.
* @package Tests.file_ical.file
* @extends Test_Case
- * @uses File_ICal_Parser
+ * @uses FS_File_ICal_Parser
* @author Christian Würker <christia...@ceusmedia.de>
* @since 19.06.2008
* @version 0.1
*/
-class Test_File_ICal_ParserTest extends Test_Case
+class Test_FS_File_ICal_ParserTest extends Test_Case
{
/**
* Constructor.
@@ -54,7 +54,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_ICal_Parser::__construct();
+ $creation = FS_File_ICal_Parser::__construct();
$this->assertEquals( $assertion, $creation );
}

@@ -67,7 +67,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_ICal_Parser::parse();
+ $creation = FS_File_ICal_Parser::parse();
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/File/INI/CreatorTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/FS/File/INI/CreatorTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_INI_Creator.
+ * TestUnit of FS_File_INI_Creator.
* @package Tests.file.ini
* @author Christian Würker <christia...@ceusmedia.de>
* @since 03.11.2008
@@ -8,15 +8,15 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_INI_Creator.
+ * TestUnit of FS_File_INI_Creator.
* @package Tests.file.ini
* @extends Test_Case
- * @uses File_INI_Creator
+ * @uses FS_File_INI_Creator
* @author Christian Würker <christia...@ceusmedia.de>
* @since 03.11.2008
* @version 0.1
*/
-class Test_File_INI_CreatorTest extends Test_Case
+class Test_FS_File_INI_CreatorTest extends Test_Case
{
/**
* Constructor.
@@ -54,7 +54,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_INI_Creator::__construct();
+ $creation = FS_File_INI_Creator::__construct();
$this->assertEquals( $assertion, $creation );
}

@@ -67,7 +67,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_INI_Creator::addProperty();
+ $creation = FS_File_INI_Creator::addProperty();
$this->assertEquals( $assertion, $creation );
}

@@ -80,7 +80,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_INI_Creator::addPropertyToSection();
+ $creation = FS_File_INI_Creator::addPropertyToSection();
$this->assertEquals( $assertion, $creation );
}

@@ -93,7 +93,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_INI_Creator::addSection();
+ $creation = FS_File_INI_Creator::addSection();
$this->assertEquals( $assertion, $creation );
}

@@ -106,7 +106,7 @@
{
$this->markTestIncomplete( 'Incomplete Test' );
$assertion = TRUE;
- $creation = File_INI_Creator::write();
+ $creation = FS_File_INI_Creator::write();
$this->assertEquals( $assertion, $creation );
}
}
=======================================
--- /branches/0.8.1/Test/File/INI/EditorTest.php Sat May 23 06:59:40 2015
UTC
+++ /branches/0.8.1/Test/FS/File/INI/EditorTest.php Thu May 28 07:36:27
2015 UTC
@@ -1,6 +1,6 @@
<?php
/**
- * TestUnit of File_INI_Editor.
+ * TestUnit of FS_File_INI_Editor.
* @package Tests.{classPackage}
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
@@ -8,22 +8,22 @@
*/
require_once 'Test/initLoaders.php';
/**
- * TestUnit of File_INI_Editor.
+ * TestUnit of FS_File_INI_Editor.
* @package Tests.{classPackage}
* @extends Test_Case
- * @uses File_INI_Editor
+ * @uses FS_File_INI_Editor
* @author Christian Würker <christia...@ceusmedia.de>
* @since 02.05.2008
* @version 0.1
*/
-class Test_File_INI_EditorTest extends Test_Case
+class Test_FS_File_INI_EditorTest extends Test_Case
{
protected $fileList;
protected $fileSections;

/** @var File_INI_Editor $list Editor for INI file without sections */
sections */
protected $list;
/** @var File_INI_Editor $sections Editor for INI file with sections */
sections */
protected $sections;

/**
@@ -47,8 +47,8 @@
{
copy( $this->path."reader.ini", $this->fileList );
copy( $this->path."reader.ini", $this->fileSections );
- $this->list = new File_INI_Editor( $this->fileList, FALSE );
- $this->sections = new File_INI_Editor( $this->fileSections, TRUE );
+ $this->list = new FS_File_INI_Editor( $this->fileList, FALSE );
+ $this->sections = new FS_File_INI_Editor( $this->fileSections, TRUE );
}

/**
@@ -71,13 +71,13 @@
*/
public function testWriteIdempotency()
{
- $assertion = File_Reader::load( $this->fileList );
+ $assertion = FS_File_Reader::load( $this->fileList );
$this->list->setProperty( "key1", "value1", "not_important" );
- $creation = File_Reader::load( $this->fileList );
+ $creation = FS_File_Reader::load( $this->fileList );

- $assertion = File_Reader::load( $this->fileSections );
+ $assertion = FS_File_Reader::load( $this->fileSections );
$this->sections->setProperty( "key1", "value1", "section1" );
- $creation = File_Reader::load( $this->fileSections );
+ $creation = FS_File_Reader::load( $this->fileSections );
}

/**
@@ -8,17 +8,17 @@
{
- /** @var File_Editor $editor Instance of File Editor */
+ /** @var FS_File_Editor $editor Instance of File Editor */
private $editor = NULL;
/** @var string $fileName File Name of Test File */
@@ -8,22 +8,22 @@
protected $fileSections;

- /** @var File_INI_Editor $list Editor for INI file without sections */
+ /** @var FS_File_INI_Editor $list Editor for INI file without
sections */
protected $list;
@@ -8,22 +8,22 @@
sections */
protected $list;
- /** @var File_INI_Editor $sections Editor for INI file with sections */
+ /** @var FS_File_INI_Editor $sections Editor for INI file with
sections */
protected $sections;
=======================================
***Additional files exist in this changeset.***
Reply all
Reply to author
Forward
0 new messages